part of 'products_bloc.dart';

abstract class ProductListEvent {}

class GetProductsEvent extends ProductListEvent {
  final String searchTxt;

  GetProductsEvent({this.searchTxt = ""});
}

class SelectProductEvent extends ProductListEvent {
  final ProductData product;

  SelectProductEvent(this.product);
}

class GetProductFilterEvent extends ProductListEvent {}

class OpenFilterEvent extends ProductListEvent {}

class SelectIntellectualFilterEvent extends ProductListEvent {
  final int id;

  SelectIntellectualFilterEvent(this.id);
}

class SelectCategoriesFilterEvent extends ProductListEvent {
  final int id;

  SelectCategoriesFilterEvent(this.id);
}

class InputPriceFromEvent extends ProductListEvent {
  final String text;

  InputPriceFromEvent(this.text);
}

class InputPriceEndEvent extends ProductListEvent {
  final String text;

  InputPriceEndEvent(this.text);
}

class SelectSortEndEvent extends ProductListEvent {
  final String sort;
  final String sort_key;

  SelectSortEndEvent(this.sort, this.sort_key);
}

class SelectPriceChoiceFilterEvent extends ProductListEvent {
  final FilterPriceChoice choice;

  SelectPriceChoiceFilterEvent(this.choice);
}

class CleanFilterEvent extends ProductListEvent {}

class CloseFilterEvent extends ProductListEvent {}

class SubmitFilterEvent extends ProductListEvent {}

class LoadMoreEvent extends ProductListEvent {}

class RefreshEvent extends ProductListEvent {}

class ShowRefreshEvent extends ProductListEvent {
  final String? textSearch;

  ShowRefreshEvent({this.textSearch});
}
